﻿using System.Drawing;
using System.Drawing.Drawing2D;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Views.Base;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 그룹 패널 이미지
        /// </summary>
        private Image groupPanelImage;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.groupPanelImage = Image.FromFile("IMAGE\\attention.png");

            this.gridView.InitializeView
            (
                true,                          // Multi Select
                GridMultiSelectMode.RowSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,  // Draw Focus Rect Style
                true,                          // Show Indicator
                true,                          // Show Column Headers
                true,                          // Allow Column Moving
                true,                          // Allow Column Resizing
                true,                          // Allow Filter
                true,                          // Allow Sort
                false,                         // Allow Cell Merge
                EditorShowMode.Default,        // Editor Show Mode
                false                          // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridView.OptionsView.ShowGroupPanel = true;

            this.gridView.OptionsView.ShowGroupedColumns = true;

            this.gridView.Appearance.GroupPanel.ForeColor = Color.Black;

            this.gridControl.DataSource = new nwindDataSetTableAdapters.OrdersTableAdapter().GetData();

            this.gridView.Columns["OrderDate"].GroupIndex = 0;

            this.gridView.BestFitColumns();

            this.gridView.CustomDrawGroupPanel += gridView_CustomDrawGroupPanel;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 뷰 그룹 패널 커스텀 그리기 - gridView_CustomDrawGroupPanel(sender, e)

        /// <summary>
        /// 그리드 뷰 그룹 패널 커스텀 그리기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_CustomDrawGroupPanel(object sender, CustomDrawEventArgs e)
        {
            Color color = Color.FromArgb(244, 132, 38);

            Brush brush = e.Cache.GetGradientBrush(e.Bounds, color, Color.Bisque, LinearGradientMode.Horizontal);

            e.Cache.FillRectangle(brush, e.Bounds);

            Rectangle rectangle = new Rectangle
            (
                e.Bounds.X +  e.Bounds.Width  - this.groupPanelImage.Size.Width - 30,
                e.Bounds.Y + (e.Bounds.Height - this.groupPanelImage.Size.Height) / 2,
                this.groupPanelImage.Width,
                this.groupPanelImage.Height
            );

            e.Cache.DrawImageUnscaled(this.groupPanelImage, rectangle);

            e.Handled = true;
        }

        #endregion
    }
}